@@ -1,8 +1,10 @@
 context('sc_year')
 
 ## dummy init list
-dil <- list('dfvars' = TRUE,
+dil <- list('sc_init_list' = TRUE,
+            'dfvars' = FALSE,
             'select' = NULL,
+            'select_order' = NULL,
             'filter' = NULL,
             'zip' = NULL,
             'year' = 'latest')
